@@ -973,9 +973,7 @@ bool MsgEdit::send()
     }
     if (bSent){
         if (data){
-            time_t now;
-            time(&now);
-            ((clientData*)data)->LastSend.value = now;
+            ((clientData*)data)->LastSend.value = time(NULL);
         }
     }else{
         if (m_msg){
@@ -1296,9 +1294,7 @@ void *MsgEdit::processEvent(Event *e)
                 }
             }else{
                 if (contact){
-                    time_t now;
-                    time(&now);
-                    contact->setLastActive(now);
+                    contact->setLastActive(time(NULL));
                     Event e(EventContactStatus, contact);
                     e.process();
                 }
