@@ -19,6 +19,7 @@
 #define _DOCKWND_H
 
 #include "simapi.h"
+#include "stl.h"
 
 #include <qwidget.h>
 #include <qtooltip.h>
@@ -27,6 +28,19 @@
 class WharfIcon;
 class DockPlugin;
 
+#ifdef WIN32
+
+typedef struct BalloonItem
+{
+    QString		text;
+    QString		title;
+    unsigned	id;
+    unsigned	flags;
+    SIM::Client	*client;
+} BallonItem;
+
+#endif
+
 class DockWnd : public QWidget, public EventReceiver
 {
     Q_OBJECT
@@ -74,9 +88,13 @@ protected:
     bool inTray;
     bool inNetTray;
     bool bInit;
+    friend class WharfIcon;
 #endif
 #else
-    void *hShell;
+    void				*hShell;
+    bool				m_bBalloon;
+    std::list<BalloonItem>	m_queue;
+    bool				showBalloon();
 #endif
     DockPlugin *m_plugin;
 };
