@@ -779,8 +779,8 @@ void GpgPlugin::unregisterMessage()
     e.process();
     Event eUse(EventRemoveMessageType, (void*)MessageGPGUse);
     eUse.process();
-    Event eUser(EventRemovePreferences, (void*)user_data_id);
-    eUser.process();
+    unsigned long id = user_data_id + 1;
+    Event(EventRemovePreferences, (void*)id).process();
 }
 
 void GpgPlugin::askPassphrase()
@@ -931,27 +931,6 @@ void *MsgGPGKey::processEvent(Event *e)
     return NULL;
 }
 
-#ifdef WIN32
-#include <windows.h>
-
-/**
- * DLL's entry point
- **/
-int WINAPI DllMain(HINSTANCE, DWORD, LPVOID)
-{
-    return TRUE;
-}
-
-/**
- * This is to prevent the CRT from loading, thus making this a smaller
- * and faster dll.
- **/
-extern "C" BOOL __stdcall _DllMainCRTStartup( HINSTANCE hinstDLL, DWORD fdwReason, LPVOID lpvReserved) {
-    return DllMain( hinstDLL, fdwReason, lpvReserved );
-}
-#endif
-
 #ifndef _MSC_VER
 #include "gpg.moc"
 #endif
-
