@@ -801,9 +801,7 @@ JabberClient::PresenceRequest::~PresenceRequest()
 {
     unsigned status = STATUS_UNKNOWN;
     bool bInvisible = false;
-    /*
-        m_type - flags after draft-ietf-xmpp-core-16 / 8.4.1
-    */
+    // RFC 3921 "XMPP IM": 2.2.1. Types of Presence
     if (m_type == "unavailable"){
         status = STATUS_OFFLINE;
     }else if (m_type == "subscribe"){
@@ -820,7 +818,7 @@ JabberClient::PresenceRequest::~PresenceRequest()
     }else if (m_type == "error"){
         log(L_DEBUG, "An error has occurred regarding processing or delivery of a previously-sent presence stanza");
     }else if (m_type.length() == 0){
-        // m_show - flags after draft-ietf-xmpp-im-15 / 4.2
+        // RFC 3921 "XMPP IM": 2.2.2.1. Show
         status = STATUS_ONLINE;
         if (m_show == "away"){
             status = STATUS_AWAY;
@@ -833,6 +831,7 @@ JabberClient::PresenceRequest::~PresenceRequest()
         }else if (m_show == "online"){
             status = STATUS_ONLINE;
         }else if (m_show.empty()){
+            // RFC 3921 "XMPP IM": 2.2.2.2. Status
             status = STATUS_ONLINE;
             if (m_status == "Online"){
                 status = STATUS_ONLINE;
@@ -886,6 +885,9 @@ JabberClient::PresenceRequest::~PresenceRequest()
                     vector<string> resourceStatus;
                     vector<string> resourceStatusTime;
                     vector<string> resourceOnlineTime;
+                    vector<string> resourceClientName;
+                    vector<string> resourceClientVersion;
+                    vector<string> resourceClientOS;
                     for (unsigned n = 1; n <= data->nResources.value; n++){
                         if (i == n)
                             continue;
@@ -894,18 +896,27 @@ JabberClient::PresenceRequest::~PresenceRequest()
                         resourceStatus.push_back(get_str(data->ResourceStatus, n));
                         resourceStatusTime.push_back(get_str(data->ResourceStatusTime, n));
                         resourceOnlineTime.push_back(get_str(data->ResourceOnlineTime, n));
+                        resourceClientName.push_back(get_str(data->ResourceClientName, n));
+                        resourceClientVersion.push_back(get_str(data->ResourceClientVersion, n));
+                        resourceClientOS.push_back(get_str(data->ResourceClientOS, n));
                     }
                     clear_list(&data->Resources);
                     clear_list(&data->ResourceReply);
                     clear_list(&data->ResourceStatus);
                     clear_list(&data->ResourceStatusTime);
                     clear_list(&data->ResourceOnlineTime);
+                    clear_list(&data->ResourceClientName);
+                    clear_list(&data->ResourceClientVersion);
+                    clear_list(&data->ResourceClientOS);
                     for (i = 0; i < resources.size(); i++){
                         set_str(&data->Resources, i + 1, resources[i].c_str());
                         set_str(&data->ResourceReply, i + 1, resourceReply[i].c_str());
                         set_str(&data->ResourceStatus, i + 1, resourceStatus[i].c_str());
                         set_str(&data->ResourceStatusTime, i + 1, resourceStatusTime[i].c_str());
                         set_str(&data->ResourceOnlineTime, i + 1, resourceOnlineTime[i].c_str());
+                        set_str(&data->ResourceClientName, i + 1, resourceClientName[i].c_str());
+                        set_str(&data->ResourceClientVersion, i + 1, resourceClientVersion[i].c_str());
+                        set_str(&data->ResourceClientOS, i + 1, resourceClientOS[i].c_str());
                     }
                     data->nResources.value = resources.size();
                 }
@@ -917,7 +928,9 @@ JabberClient::PresenceRequest::~PresenceRequest()
                     data->nResources.value = i;
                     set_str(&data->Resources, i, resource.c_str());
                     set_str(&data->ResourceOnlineTime, i, number(time2 ? time2 : time1).c_str());
-                }
+                    if (m_client->getUseVersion())
+                        m_client->versionInfo(m_from.c_str());
+               }
                 if (number(status) != get_str(data->ResourceStatus, i)){
                     bChanged = true;
                     set_str(&data->ResourceStatus, i, number(status).c_str());
@@ -945,6 +958,11 @@ JabberClient::PresenceRequest::~PresenceRequest()
                     data->OnlineTime.value = time1;
                     data->richText.bValue = true;
                 }
+                if (status == STATUS_OFFLINE && data->IsTyping.bValue){
+                    data->IsTyping.bValue = false;
+                    Event e(EventContactStatus, contact);
+                    e.process();
+                }                  
                 data->Status.value = status;
                 data->StatusTime.value = time1;
             }
@@ -1078,6 +1096,7 @@ void JabberClient::IqRequest::element_start(const char *el, const char **attr)
     if (!strcmp(el, "iq")){
         m_from = JabberClient::get_attr("from", attr);
         m_id   = JabberClient::get_attr("id", attr);
+        m_type = JabberClient::get_attr("type", attr);
         return;
     }
     if (!strcmp(el, "query")){
@@ -1121,6 +1140,20 @@ void JabberClient::IqRequest::element_start(const char *el, const char **attr)
                     }
                 }
             }
+        // XEP-0092: Software Version
+        }else if (m_query == "jabber:iq:version"){
+            if (m_type == "get" && m_client->getUseVersion()){
+                // send our version
+                JabberClient::ServerRequest *req = new JabberClient::ServerRequest(m_client, JabberClient::ServerRequest::_RESULT, NULL, m_from.c_str(), m_id.c_str());
+                req->start_element("query");
+                req->add_attribute("xmlns", "jabber:iq:version");
+                req->text_tag("name", PACKAGE);
+                req->text_tag("version", VERSION);
+                QString version = get_os_version();
+                req->text_tag("os", version);
+                req->send();
+                m_client->m_requests.push_back(req);
+            }
         }
     }
     if (!strcmp(el, "url"))
@@ -1255,35 +1288,32 @@ JabberClient::MessageRequest::~MessageRequest()
         contact->setFlags(CONTACT_TEMP);
     }
     Message *msg = NULL;
-    if (!m_id.empty()){
-        if (m_bError)
-            return;
-        string typing_id;
-        if (data->TypingId.ptr)
-            typing_id = data->TypingId.ptr;
-        string new_typing_id;
-        bool bProcess = false;
-        while (!typing_id.empty()){
-            string id = getToken(typing_id, ';');
-            if (id == m_id){
-                if (!m_bCompose)
-                    continue;
-                bProcess = true;
+
+    if (!m_bError){
+        // JEP-0022 composing event handling
+        if (m_bBody){
+            // Msg contains normal message. 
+            // <composing/> here means "send me composing events, please", so we should do it.
+            // But if that tag is absent, we must not send them.
+            data->SendTypingEvents.bValue = m_bCompose;
+            set_str(&data->TypingId.ptr, (m_bCompose ? m_id.c_str() : NULL));
+
+            // also, incoming message implicitly means that user has stopped typing
+            if (data->IsTyping.bValue){
+                data->IsTyping.bValue = false;
+                Event e(EventContactStatus, contact);
+                e.process();
             }
-            if (!new_typing_id.empty())
-                new_typing_id += ";";
-            new_typing_id += id;
         }
-        if (!bProcess && m_bCompose){
-            if (!new_typing_id.empty())
-                new_typing_id += ";";
-            new_typing_id += m_id;
-        }
-        if (set_str(&data->TypingId.ptr, new_typing_id.c_str())){
+        else{
+            // Msg has no body ==> it is event message. 
+            // Presence of <composing/> here means "I'm typing", absence - "I'm not typing anymore".
+            data->IsTyping.bValue = m_bCompose;
             Event e(EventContactStatus, contact);
             e.process();
         }
     }
+
     if (m_errorCode || !m_error.empty()){
         if (!m_bEvent){
             JabberMessageError *m = new JabberMessageError;
@@ -1362,6 +1392,7 @@ void JabberClient::MessageRequest::element_start(const char *el, const char **at
     m_data = NULL;
     if (!strcmp(el, "message")){
         m_from = JabberClient::get_attr("from", attr);
+        m_id = JabberClient::get_attr("id", attr);
         if (JabberClient::get_attr("type", attr) == "error")
             m_bError = true;
         return;
@@ -1380,12 +1411,10 @@ void JabberClient::MessageRequest::element_start(const char *el, const char **at
         m_data = &m_error;
         return;
     }
-    if (!strcmp(el, "composing")){
-        m_bCompose = true;
-        return;
-    }
-    if (!strcmp(el, "id")){
-        m_data = &m_id;
+    if (m_bEvent){
+        // Parsing <x xmlns='jabber:x:event'> tag, which contains JEP-0022 event info
+        if (!strcmp(el, "composing"))
+            m_bCompose = true;
         return;
     }
     if (!strcmp(el, "url-data")){
@@ -2608,32 +2637,37 @@ string JabberClient::browse(const char *jid)
 class VersionInfoRequest : public JabberClient::ServerRequest
 {
 public:
-    VersionInfoRequest(JabberClient *client, const char *jid);
+    VersionInfoRequest(JabberClient *client, const char *jid, const char *node);
     ~VersionInfoRequest();
 protected:
     virtual void	element_start(const char *el, const char **attr);
     virtual void	element_end(const char *el);
     virtual	void	char_data(const char *str, int len);
     string			*m_data;
+    string			m_jid;
+    string			m_node;
     string			m_name;
     string			m_version;
     string			m_os;
 };
 
-VersionInfoRequest::VersionInfoRequest(JabberClient *client, const char *jid)
+VersionInfoRequest::VersionInfoRequest(JabberClient *client, const char *jid, const char *node)
         : JabberClient::ServerRequest(client, _GET, NULL, jid)
 {
     m_data = NULL;
+    m_jid = jid;
+    m_node = node;
 }
 
 VersionInfoRequest::~VersionInfoRequest()
 {
-    DiscoItem item;
-    item.id		= m_id;
-    item.jid	= m_version;
-    item.name	= m_name;
-    item.node	= m_os;
-    Event e(EventDiscoItem, &item);
+    ClientVersionInfo info;
+    info.jid = m_jid;
+    info.node = m_node;
+    info.name = m_name;
+    info.version = m_version;
+    info.os = m_os;
+    Event e(EventClientVersion, &info);
     e.process();
 }
 
@@ -2662,7 +2696,7 @@ string JabberClient::versionInfo(const char *jid, const char *node)
 {
     if (getState() != Connected)
         return "";
-    VersionInfoRequest *req = new VersionInfoRequest(this, jid);
+    VersionInfoRequest *req = new VersionInfoRequest(this, jid, node);
     req->start_element("query");
     req->add_attribute("xmlns", "jabber:iq:version");
     if (node && *node)
