@@ -276,7 +276,7 @@ static CommandDef livejournal_descr =
         I18N_NOOP("LiveJournal"),
         "LiveJournal",
         NULL,
-        NULL,
+        "http://www.livejournal.com/lostinfo.bml",
         0,
         0,
         0,
@@ -551,11 +551,8 @@ MessageRequest::MessageRequest(LiveJournalClient *client, JournalMessage *msg, c
     addParam("lineendings", "unix");
     if (msg->getID())
         addParam("itemid", number(msg->getID()).c_str());
-    if (msg->getTime() == 0){
-        time_t now;
-        time(&now);
-        msg->setTime(now);
-    }
+    if (msg->getTime() == 0)
+        msg->setTime(time(NULL));
     time_t now;
     now = msg->getTime();
     struct tm *tm = localtime(&now);
@@ -1515,29 +1512,6 @@ I18N_NOOP("Journal Settings")
 
 #endif
 
-#ifdef WIN32
-#include <windows.h>
-
-/**
- * DLL's entry point
- **/
-int WINAPI DllMain(HINSTANCE, DWORD, LPVOID)
-{
-    return TRUE;
-}
-
-/**
- * This is to prevent the CRT from loading, thus making this a smaller
- * and faster dll.
- **/
-extern "C" BOOL __stdcall _DllMainCRTStartup( HINSTANCE hinstDLL, DWORD fdwReason, LPVOID lpvReserved) {
-    return DllMain( hinstDLL, fdwReason, lpvReserved );
-}
-
-#endif
-
 #ifndef _MSC_VER
 #include "livejournal.moc"
 #endif
-
-
