@@ -29,8 +29,8 @@
 #include <arpa/inet.h>
 #endif
 
+#include <stdio.h>
 #include <qtimer.h>
-#include <openssl/md5.h>
 
 MSNPacket::MSNPacket(MSNClient *client, const char *cmd)
 {
@@ -249,9 +249,9 @@ void SynPacket::answer(vector<string> &args)
         m_ver = atol(args[0].c_str());
     m_client->m_nBuddies = 0;
     m_client->m_nGroups  = 0;
-    if (!args[1].empty())
+    if ((args.size() > 1) && !args[1].empty())
         m_client->m_nBuddies = atol(args[1].c_str());
-    if (!args[2].empty())
+    if ((args.size() > 2) && !args[2].empty())
         m_client->m_nGroups  = atol(args[2].c_str());
     m_client->setListVer(m_ver);
     ContactList::GroupIterator itg;
@@ -261,7 +261,8 @@ void SynPacket::answer(vector<string> &args)
         ClientDataIterator it(grp->clientData, m_client);
         while ((data = (MSNUserData*)(++it)) != NULL){
             data->sFlags.value = data->Flags.value;
-            data->Flags.value  = 0;
+            if (args.size() > 1)
+                data->Flags.value  = 0;
         }
     }
     ContactList::ContactIterator itc;
@@ -271,7 +272,8 @@ void SynPacket::answer(vector<string> &args)
         ClientDataIterator it(contact->clientData, m_client);
         while ((data = (MSNUserData*)(++it)) != NULL){
             data->sFlags.value = data->Flags.value;
-            data->Flags.value  = 0;
+            if (args.size() > 1)
+                data->Flags.value  = 0;
         }
     }
 }
@@ -283,15 +285,12 @@ QryPacket::QryPacket(MSNClient *client, const char *qry)
     addArg("32");
     m_line += "\r\n";
     char qry_add[] = "VT6PX?UQTM4WM%YR";
-    MD5_CTX c;
-    unsigned char md[MD5_DIGEST_LENGTH];
-    MD5_Init(&c);
-    MD5_Update(&c, qry, (unsigned long)strlen(qry));
-    MD5_Update(&c, qry_add, (unsigned long)strlen(qry_add));
-    MD5_Final(md, &c);
-    for (unsigned i = 0; i < MD5_DIGEST_LENGTH; i++){
+    string md = qry;
+    md += qry_add;
+    md = md5(md.c_str());
+    for (unsigned i = 0; i < md.length(); i++){
         char b[3];
-        sprintf(b, "%02x",md[i]);
+        sprintf(b, "%02x", md[i] & 0xFF);
         m_line += b;
     }
 }
@@ -421,8 +420,11 @@ MSNServerMessage::MSNServerMessage(MSNClient *client, unsigned size)
     m_size   = size;
 }
 
+typedef map<QString, QString> KEY_MAP;
+
 MSNServerMessage::~MSNServerMessage()
 {
+    KEY_MAP values;
     QString msg = QString::fromUtf8(m_msg.c_str());
     for (;!msg.isEmpty();){
         QString line;
@@ -437,10 +439,66 @@ MSNServerMessage::~MSNServerMessage()
         n = line.find(":");
         if (n < 0)
             continue;
-        QString key = line.left(n);
-        QString value = trim(line.mid(n + 1));
-        if (key == "ClientIP")
-            set_ip(&m_client->data.owner.IP, inet_addr(value.latin1()));
+        values.insert(KEY_MAP::value_type(line.left(n), trim(line.mid(n + 1))));
+    }
+    KEY_MAP::iterator it = values.find("ClientIP");
+    if (it != values.end())
+        set_ip(&m_client->data.owner.IP, inet_addr((*it).second.latin1()));
+    it = values.find("Content-Type");
+    if (it != values.end()){
+        QString content_type = (*it).second;
+        content_type = getToken(content_type, ';');
+        if (content_type == "text/x-msmsgsinitialemailnotification"){
+            m_client->m_init_mail = "";
+            it = values.find("Post-URL");
+            if (it != values.end())
+                m_client->m_init_mail = (*it).second.latin1();
+            it = values.find("Inbox-URL");
+            if (it != values.end())
+                m_client->m_init_mail += (*it).second.latin1();
+            it = values.find("Inbox-Unread");
+            if (it == values.end())
+                return;
+            unsigned nUnread = (*it).second.toUInt();
+            if (nUnread){
+                clientErrorData data;
+                data.client		= m_client;
+                data.err_str	= "%1";
+                data.options	= NULL;
+                data.args		= strdup(i18n("You have %n unread message.", "You have %n unread messages.", nUnread).utf8());
+                data.code		= 0;
+                data.flags		= ERR_INFO;
+                data.id			= static_cast<MSNPlugin*>(m_client->protocol()->plugin())->MSNInitMail;
+                Event e(EventShowError, &data);
+                e.process();
+            }
+        }
+        if (content_type == "text/x-msmsgsemailnotification"){
+            m_client->m_new_mail = "";
+            it = values.find("Post-URL");
+            if (it != values.end())
+                m_client->m_new_mail = (*it).second.latin1();
+            it = values.find("Message-URL");
+            if (it != values.end())
+                m_client->m_new_mail += (*it).second.latin1();
+            QString from;
+            it = values.find("From-Addr");
+            if (it != values.end())
+                from = (*it).second;
+            QString msg = i18n("You have new mail");
+            if (!from.isEmpty())
+                msg = i18n("%1 from %2") .arg(msg) .arg(from);
+            clientErrorData data;
+            data.client		= m_client;
+            data.err_str	= "%1";
+            data.options	= NULL;
+            data.args		= strdup(msg.utf8());
+            data.code		= 0;
+            data.flags		= ERR_INFO;
+            data.id			= static_cast<MSNPlugin*>(m_client->protocol()->plugin())->MSNNewMail;
+            Event e(EventShowError, &data);
+            e.process();
+        }
     }
 }
 
