@@ -29,6 +29,13 @@ typedef struct OSDUserData
     Data    EnableMessageShowContent;
     Data	ContentLines;
     Data	EnableAlert;
+    Data	EnableAlertOnline;
+    Data	EnableAlertAway;
+    Data	EnableAlertNA;
+    Data	EnableAlertDND;
+    Data	EnableAlertOccupied;
+    Data	EnableAlertFFC;
+    Data	EnableAlertOffline;
     Data	EnableTyping;
     Data	Position;
     Data	Offset;
@@ -44,7 +51,13 @@ typedef struct OSDUserData
 enum OSDType
 {
     OSD_NONE,
-    OSD_ALERT,
+    OSD_ALERTONLINE,
+    OSD_ALERTAWAY,
+    OSD_ALERTNA,
+    OSD_ALERTDND,
+    OSD_ALERTOCCUPIED,
+    OSD_ALERTFFC,
+    OSD_ALERTOFFLINE,
     OSD_TYPING,
     OSD_MESSAGE
 };
@@ -56,6 +69,7 @@ typedef struct OSDRequest
 } OSDRequest;
 
 class QTimer;
+class QPushButton;
 class CorePlugin;
 
 class OSDWidget : public QWidget
@@ -66,12 +80,16 @@ public:
     void showOSD(const QString &text, OSDUserData *data);
 signals:
     void dblClick();
+    void closeClick();
+protected slots:
+    void slotCloseClick();
 protected:
     bool isScreenSaverActive();
     void paintEvent(QPaintEvent*);
     void mouseDoubleClickEvent(QMouseEvent *e);
     QFont	baseFont;
     QPixmap bgPict;
+    QPushButton	*m_button;
 };
 
 class OSDPlugin : public QObject, public Plugin, public EventReceiver
@@ -80,10 +98,11 @@ class OSDPlugin : public QObject, public Plugin, public EventReceiver
 public:
     OSDPlugin(unsigned);
     virtual ~OSDPlugin();
-    unsigned user_data_id;
+    unsigned long user_data_id;
 protected slots:
     void timeout();
     void dblClick();
+    void closeClick();
 protected:
     virtual QWidget *createConfigWindow(QWidget *parent);
     virtual void *processEvent(Event*);
