@@ -278,8 +278,7 @@ void FetchThread::run()
                 }
                 if (m_client->m_speed){
                     m_client->m_sendSize += tail;
-                    time_t now;
-                    time(&now);
+                    time_t now = time(NULL);
                     if ((unsigned)now != m_client->m_sendTime){
                         m_client->m_sendTime = now;
                         m_client->m_sendSize = 0;
@@ -447,48 +446,7 @@ FetchManager::FetchManager()
 {
     m_done = new list<FetchClientPrivate*>;
     user_agent = "Mozilla/4.0 (" PACKAGE "/" VERSION " ";
-#ifdef WIN32
-    user_agent += "Windows ";
-    OSVERSIONINFOA osvi;
-    osvi.dwOSVersionInfoSize = sizeof(osvi);
-    GetVersionExA(&osvi);
-    switch (osvi.dwPlatformId){
-    case VER_PLATFORM_WIN32_NT:
-        if ((osvi.dwMajorVersion == 5) && (osvi.dwMinorVersion == 2)){
-            user_agent += "2003";
-        }else if ((osvi.dwMajorVersion == 5) && (osvi.dwMinorVersion == 1)){
-            user_agent += "XP";
-        }else if ((osvi.dwMajorVersion == 5) && (osvi.dwMinorVersion == 0 )){
-            user_agent += "2000";
-        }else{
-            user_agent += "NT ";
-            user_agent += number(osvi.dwMajorVersion);
-            user_agent += ".";
-            user_agent += number(osvi.dwMinorVersion);
-        }
-        break;
-    case VER_PLATFORM_WIN32_WINDOWS:
-        if (osvi.dwMajorVersion == 4){
-            if (osvi.dwMinorVersion == 0){
-                user_agent += "95";
-                if ((osvi.szCSDVersion[1] == 'C') || (osvi.szCSDVersion[1] == 'B'))
-                    user_agent += " OSR2";
-            }else if (osvi.dwMinorVersion == 10){
-                user_agent += "98";
-                if ( osvi.szCSDVersion[1] == 'A' )
-                    user_agent += " SE";
-            }else if (osvi.dwMinorVersion == 90){
-                user_agent += "Millennium";
-            }
-        }
-        break;
-    case VER_PLATFORM_WIN32s:
-        user_agent += "32s";
-        break;
-    }
-#else
-    user_agent += UNAME;
-#endif
+    user_agent += get_os_version();
     user_agent += ")";
 #ifdef WIN32
     HINSTANCE hLib = LoadLibraryA("wininet.dll");
@@ -509,7 +467,7 @@ FetchManager::FetchManager()
         (DWORD&)_InternetErrorDlg = (DWORD)GetProcAddress(hLib, "InternetErrorDlg");
     }
     if (_InternetOpen && _HttpSendRequestEx){
-        hInet = _InternetOpen(user_agent.c_str(), INTERNET_OPEN_TYPE_PRECONFIG, NULL, NULL, 0);
+        hInet = _InternetOpen(user_agent.latin1(), INTERNET_OPEN_TYPE_PRECONFIG, NULL, NULL, 0);
         if (hInet == NULL)
             log(L_WARN, "Internet open error %u", GetLastError());
     }
@@ -862,7 +820,7 @@ void FetchClientPrivate::connect_ready()
         << "\r\n";
     if (!findHeader("User-Agent"))
         m_socket->writeBuffer
-        << "User-Agent: " << FetchManager::manager->user_agent.c_str() << "\r\n";
+        << "User-Agent: " << FetchManager::manager->user_agent.latin1() << "\r\n";
     if (!findHeader("Authorization") && !user.empty())
         m_socket->writeBuffer
         << "Authorization: basic "
@@ -909,8 +867,7 @@ void FetchClientPrivate::write_ready()
     m_socket->write();
     if (m_speed){
         m_sendSize += tail;
-        time_t now;
-        time(&now);
+        time_t now = time(NULL);
         if ((unsigned)now != m_sendTime){
             m_sendTime = now;
             m_sendSize = 0;
@@ -1046,7 +1003,9 @@ const char *FetchClient::read_data(char*, unsigned &size)
     unsigned tail = p->m_postData->size() - p->m_postData->readPos();
     if (size > tail)
         size = tail;
-    return p->m_postData->data(p->m_postData->readPos());
+    const char* res = p->m_postData->data(p->m_postData->readPos());
+    p->m_postData->incReadPos(size);
+    return res;
 }
 
 bool FetchClient::write_data(const char *buf, unsigned size)
