@@ -28,27 +28,30 @@
 #include "builtinlogger.h"
 
 #ifdef WIN32
-#include "qjpegio.h"
 #include <windows.h>
 #else
 #include <ctype.h>
 #endif
 
 #ifndef  LTDL_SHLIB_EXT
-#if !defined(QT_MACOSX_VERSION) && !defined(QT_MAC)
-#define  LTDL_SHLIB_EXT ".so"
-#else	/* MacOS needs .a */
-#define  LTDL_SHLIB_EXT ".a"
-#endif
+# if defined(QT_MACOSX_VERSION) || defined(QT_MAC) /* MacOS needs .a */
+#  define  LTDL_SHLIB_EXT ".a"
+# else
+#  if defined(_WIN32) || defined(_WIN64)
+#   define  LTDL_SHLIB_EXT ".dll"
+#  else
+#   define  LTDL_SHLIB_EXT ".so"
+#  endif
+# endif
 #endif
 
-#include "libltdl/ltdl.h"
 #include <errno.h>
 #include <qdir.h>
 #include <qstringlist.h>
 #include <qmessagebox.h>
 #include <qapplication.h>
 #include <qregexp.h>
+#include <qlibrary.h>
 
 #include <memory>
 #include <algorithm>
@@ -177,10 +180,6 @@ PluginManagerPrivate::PluginManagerPrivate(int argc, char **argv)
     m_bLoaded = false;
     m_bInInit = true;
 
-    lt_dlinit();
-#ifdef WIN32
-    qInitJpegIO();
-#endif
 
     QStringList pluginsList;
 #ifdef WIN32
@@ -255,7 +254,6 @@ PluginManagerPrivate::~PluginManagerPrivate()
     release_all(NULL);
     delete m_exec;
     setLogEnable(false);
-    lt_dlexit();
     XSL::cleanup();
     SAXParser::cleanup();
 }
@@ -353,17 +351,17 @@ void PluginManagerPrivate::load(pluginInfo &info)
         pluginName += info.name;
         pluginName += LTDL_SHLIB_EXT;
         string fullName = app_file(pluginName.c_str());
-        info.module = (void*)lt_dlopen(fullName.c_str());
+        info.module = new QLibrary(fullName.c_str());
         if (info.module == NULL)
-            fprintf(stderr, "Can't load plugin %s: %s\n", info.name.c_str(), lt_dlerror());
+            fprintf(stderr, "Can't load plugin %s\n", info.name.c_str());
     }
     if (info.module == NULL)
         return;
     if (info.info == NULL){
         PluginInfo* (*getInfo)() = NULL;
-        (lt_ptr&)getInfo = lt_dlsym((lt_dlhandle)info.module, "GetPluginInfo");
+        getInfo = (PluginInfo* (*)()) info.module->resolve("GetPluginInfo");
         if (getInfo == NULL){
-            fprintf(stderr, "Plugin %s hasn't entry GetPluginInfo\n", info.name.c_str());
+            fprintf(stderr, "Plugin %s doesn't have the GetPluginInfo entry\n", info.name.c_str());
             release(info);
             return;
         }
@@ -502,7 +500,7 @@ void PluginManagerPrivate::release(pluginInfo &info, bool bFree)
     }
     if (info.module){
         if (bFree)
-            lt_dlclose((lt_dlhandle)info.module);
+            delete info.module;
         info.module = NULL;
     }
     info.info = NULL;
