@@ -173,6 +173,7 @@ protected:
 class QFile;
 class QWidget;
 class QIconSet;
+class QLibrary;
 class QPixmap;
 class QToolBar;
 class QMainWindow;
@@ -259,7 +260,7 @@ typedef struct pluginInfo
     bool			bDisabled;		// no load this plugin
     bool			bNoCreate;		// can't create plugin
     bool			bFromCfg;		// init state from config
-    void			*module;		// so or dll handle
+    QLibrary			*module;		// so or dll handle
     PluginInfo		*info;
     unsigned		base;			// base for plugin types
 } pluginInfo;
@@ -1823,5 +1824,5 @@ EXPORT void setLogEnable(bool);
 using namespace SIM;
 
 EXPORT QString g_i18n(const char *text, Contact *contact);
-
+EXPORT QString get_os_version();
 #endif
